@@ -1,13 +1,11 @@
 //! Calculate which nearby lines should also be displayed.
 
 use std::cmp::Ordering;
-use std::collections::HashSet;
 
 use line_numbers::LineNumber;
-use rustc_hash::FxHashSet;
 
 use crate::{
-    hash::DftHashMap,
+    hash::{DftHashMap, DftHashSet},
     parse::syntax::{zip_repeat_shorter, MatchKind, MatchedPos},
 };
 
@@ -124,7 +122,7 @@ fn all_matched_lines(
 }
 
 fn all_lines(mps: &[MatchedPos]) -> Vec<LineNumber> {
-    let mut lines = FxHashSet::default();
+    let mut lines = DftHashSet::default();
     for mp in mps {
         lines.insert(mp.pos.line);
     }
@@ -329,8 +327,8 @@ fn match_preceding_blanks(
 
 pub(crate) fn opposite_positions(
     mps: &[MatchedPos],
-) -> DftHashMap<LineNumber, HashSet<LineNumber>> {
-    let mut res: DftHashMap<LineNumber, HashSet<LineNumber>> = DftHashMap::default();
+) -> DftHashMap<LineNumber, DftHashSet<LineNumber>> {
+    let mut res: DftHashMap<LineNumber, DftHashSet<LineNumber>> = DftHashMap::default();
 
     for mp in mps {
         match &mp.kind {
@@ -340,7 +338,9 @@ pub(crate) fn opposite_positions(
                 ..
             } => {
                 for (self_span, opposite_span) in zip_repeat_shorter(self_pos, opposite_pos) {
-                    let opposite_lines = res.entry(self_span.line).or_insert_with(HashSet::new);
+                    let opposite_lines = res
+                        .entry(self_span.line)
+                        .or_insert_with(DftHashSet::default);
                     opposite_lines.insert(opposite_span.line);
                 }
             }
@@ -349,7 +349,7 @@ pub(crate) fn opposite_positions(
                 self_pos,
                 ..
             } => {
-                let opposite_lines = res.entry(self_pos.line).or_insert_with(HashSet::new);
+                let opposite_lines = res.entry(self_pos.line).or_insert_with(DftHashSet::default);
                 for opposite_span in opposite_pos {
                     opposite_lines.insert(opposite_span.line);
                 }
@@ -378,7 +378,7 @@ pub(crate) fn opposite_positions(
 /// ```
 fn before_with_opposites(
     before_lines: &[LineNumber],
-    opposite_lines: &DftHashMap<LineNumber, HashSet<LineNumber>>,
+    opposite_lines: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
 ) -> Vec<(Option<LineNumber>, Option<LineNumber>)> {
     let mut lines = before_lines.to_vec();
     lines.reverse();
@@ -474,7 +474,7 @@ pub(crate) fn flip_tuples<Tx: Copy, Ty: Copy>(items: &[(Tx, Ty)]) -> Vec<(Ty, Tx
 /// 122    91 (closest match)
 fn after_with_opposites(
     after_lines: &[LineNumber],
-    opposite_lines: &DftHashMap<LineNumber, HashSet<LineNumber>>,
+    opposite_lines: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
     prev_max_opposite: Option<LineNumber>,
     max_opposite: LineNumber,
 ) -> Vec<(Option<LineNumber>, Option<LineNumber>)> {
@@ -517,8 +517,8 @@ fn after_with_opposites(
 
 pub(crate) fn calculate_before_context(
     lines: &[(Option<LineNumber>, Option<LineNumber>)],
-    opposite_to_lhs: &DftHashMap<LineNumber, HashSet<LineNumber>>,
-    opposite_to_rhs: &DftHashMap<LineNumber, HashSet<LineNumber>>,
+    opposite_to_lhs: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
+    opposite_to_rhs: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
     num_context_lines: usize,
 ) -> Vec<(Option<LineNumber>, Option<LineNumber>)> {
     match lines.first() {
@@ -539,8 +539,8 @@ pub(crate) fn calculate_before_context(
 
 pub(crate) fn calculate_after_context(
     lines: &[(Option<LineNumber>, Option<LineNumber>)],
-    opposite_to_lhs: &DftHashMap<LineNumber, HashSet<LineNumber>>,
-    opposite_to_rhs: &DftHashMap<LineNumber, HashSet<LineNumber>>,
+    opposite_to_lhs: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
+    opposite_to_rhs: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
     max_lhs_src_line: LineNumber,
     max_rhs_src_line: LineNumber,
     num_context_lines: usize,
@@ -589,8 +589,8 @@ pub(crate) fn calculate_after_context(
 
 pub(crate) fn add_context(
     lines: &[(Option<LineNumber>, Option<LineNumber>)],
-    opposite_to_lhs: &DftHashMap<LineNumber, HashSet<LineNumber>>,
-    opposite_to_rhs: &DftHashMap<LineNumber, HashSet<LineNumber>>,
+    opposite_to_lhs: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
+    opposite_to_rhs: &DftHashMap<LineNumber, DftHashSet<LineNumber>>,
     max_lhs_src_line: LineNumber,
     max_rhs_src_line: LineNumber,
     num_context_lines: usize,
@@ -743,10 +743,10 @@ mod tests {
         let lines = vec![(Some(1.into()), Some(1.into()))];
 
         let mut opposite_to_lhs = DftHashMap::default();
-        opposite_to_lhs.insert(0.into(), HashSet::from_iter([0.into()]));
+        opposite_to_lhs.insert(0.into(), DftHashSet::from_iter([0.into()]));
 
         let mut opposite_to_rhs = DftHashMap::default();
-        opposite_to_rhs.insert(0.into(), HashSet::from_iter([0.into()]));
+        opposite_to_rhs.insert(0.into(), DftHashSet::from_iter([0.into()]));
 
         let res = calculate_before_context(
             &lines,
