@@ -1,7 +1,5 @@
 //! Load and configure parsers written with tree-sitter.
 
-use std::collections::HashSet;
-
 use line_numbers::LinePositions;
 use streaming_iterator::StreamingIterator as _;
 use tree_sitter as ts;
@@ -9,7 +7,7 @@ use typed_arena::Arena;
 
 use super::syntax::MatchedPos;
 use super::syntax::{self, StringKind};
-use crate::hash::DftHashMap;
+use crate::hash::{DftHashMap, DftHashSet};
 use crate::options::DiffOptions;
 use crate::parse::guess_language as guess;
 use crate::parse::syntax::{AtomKind, Syntax};
@@ -45,7 +43,7 @@ pub(crate) struct TreeSitterConfig {
     /// all the children in the source. This is known limitation of
     /// tree-sitter, and occurs more often for complex string syntax.
     /// <https://github.com/tree-sitter/tree-sitter/issues/1156>
-    atom_nodes: HashSet<&'static str>,
+    atom_nodes: DftHashSet<&'static str>,
 
     /// We want to consider delimiter tokens as part of lists, not
     /// standalone atoms. Tree-sitter includes delimiter tokens, so
@@ -69,7 +67,6 @@ extern "C" {
     fn tree_sitter_dart() -> ts::Language;
     fn tree_sitter_devicetree() -> ts::Language;
     fn tree_sitter_elisp() -> ts::Language;
-    fn tree_sitter_elixir() -> ts::Language;
     fn tree_sitter_elm() -> ts::Language;
     fn tree_sitter_elvish() -> ts::Language;
     fn tree_sitter_erlang() -> ts::Language;
@@ -81,15 +78,12 @@ extern "C" {
     fn tree_sitter_janet_simple() -> ts::Language;
     fn tree_sitter_kotlin() -> ts::Language;
     fn tree_sitter_latex() -> ts::Language;
-    fn tree_sitter_make() -> ts::Language;
     fn tree_sitter_newick() -> ts::Language;
-    fn tree_sitter_nix() -> ts::Language;
     fn tree_sitter_pascal() -> ts::Language;
     fn tree_sitter_perl() -> ts::Language;
     fn tree_sitter_qmljs() -> ts::Language;
     fn tree_sitter_r() -> ts::Language;
     fn tree_sitter_racket() -> ts::Language;
-    fn tree_sitter_rust() -> ts::Language;
     fn tree_sitter_scheme() -> ts::Language;
     fn tree_sitter_smali() -> ts::Language;
     fn tree_sitter_scss() -> ts::Language;
@@ -97,7 +91,6 @@ extern "C" {
     fn tree_sitter_sql() -> ts::Language;
     fn tree_sitter_swift() -> ts::Language;
     fn tree_sitter_vhdl() -> ts::Language;
-    fn tree_sitter_yaml() -> ts::Language;
     fn tree_sitter_zig() -> ts::Language;
 }
 
@@ -118,7 +111,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_ada() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_literal", "character_literal"]
+                atom_nodes: ["string_literal", "character_literal"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("(", ")"), ("[", "]")],
@@ -134,7 +127,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_apex() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "string_literal",
                     "null_literal",
                     "boolean",
@@ -160,7 +153,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "raw_string", "heredoc_body"]
+                atom_nodes: ["string", "raw_string", "heredoc_body"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
@@ -174,7 +167,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_literal", "char_literal"].into_iter().collect(),
+                atom_nodes: ["string_literal", "char_literal"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(&language, tree_sitter_c::HIGHLIGHT_QUERY).unwrap(),
                 sub_languages: vec![],
@@ -191,7 +184,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 language: language.clone(),
                 // The C++ grammar extends the C grammar, so the node
                 // names are generally the same.
-                atom_nodes: vec!["string_literal", "char_literal"].into_iter().collect(),
+                atom_nodes: ["string_literal", "char_literal"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(&language, &highlight_query).unwrap(),
                 sub_languages: vec![],
@@ -201,7 +194,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_clojure() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["kwd_lit", "regex_lit"].into_iter().collect(),
+                atom_nodes: ["kwd_lit", "regex_lit"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")]
                     .into_iter()
                     .collect(),
@@ -217,7 +210,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_cmake() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["argument"].into_iter().collect(),
+                atom_nodes: ["argument"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")].into_iter().collect(),
                 highlight_query: ts::Query::new(
                     &language,
@@ -231,7 +224,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_commonlisp() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["str_lit", "char_lit"].into_iter().collect(),
+                atom_nodes: ["str_lit", "char_lit"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")],
                 highlight_query: ts::Query::new(&language, "").unwrap(),
                 sub_languages: vec![],
@@ -242,7 +235,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "string_literal",
                     "verbatim_string_literal",
                     "character_literal",
@@ -265,7 +258,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "integer_value",
                     "float_value",
                     "color_value",
@@ -283,7 +276,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_dart() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_literal", "script_tag"].into_iter().collect(),
+                atom_nodes: ["string_literal", "script_tag"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -297,7 +290,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_devicetree() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["byte_string_literal", "string_literal"]
+                atom_nodes: ["byte_string_literal", "string_literal"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("<", ">"), ("{", "}"), ("(", ")")],
@@ -309,35 +302,18 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
-        EmacsLisp => {
-            let language = unsafe { tree_sitter_elisp() };
-            TreeSitterConfig {
-                language: language.clone(),
-                atom_nodes: vec![].into_iter().collect(),
-                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")]
-                    .into_iter()
-                    .collect(),
-                highlight_query: ts::Query::new(
-                    &language,
-                    include_str!("../../vendored_parsers/highlights/elisp.scm"),
-                )
-                .unwrap(),
-                sub_languages: vec![],
-            }
-        }
         Elixir => {
-            let language = unsafe { tree_sitter_elixir() };
+            let language_fn = tree_sitter_elixir::LANGUAGE;
+            let language = tree_sitter::Language::new(language_fn);
+
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "heredoc"].into_iter().collect(),
+                atom_nodes: vec!["string", "sigil", "heredoc"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("do", "end")]
                     .into_iter()
                     .collect(),
-                highlight_query: ts::Query::new(
-                    &language,
-                    include_str!("../../vendored_parsers/highlights/elixir.scm"),
-                )
-                .unwrap(),
+                highlight_query: ts::Query::new(&language, tree_sitter_elixir::HIGHLIGHTS_QUERY)
+                    .unwrap(),
                 sub_languages: vec![],
             }
         }
@@ -345,7 +321,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_elm() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_constant_expr"].into_iter().collect(),
+                atom_nodes: ["string_constant_expr"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("[", "]"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -359,7 +335,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_elvish() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: [].into(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("|", "|")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -369,11 +345,27 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        EmacsLisp => {
+            let language = unsafe { tree_sitter_elisp() };
+            TreeSitterConfig {
+                language: language.clone(),
+                atom_nodes: [].into_iter().collect(),
+                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")]
+                    .into_iter()
+                    .collect(),
+                highlight_query: ts::Query::new(
+                    &language,
+                    include_str!("../../vendored_parsers/highlights/elisp.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Erlang => {
             let language = unsafe { tree_sitter_erlang() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: [].into(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -387,7 +379,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_fsharp() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: ["string", "triple_quoted_string"].into(),
+                atom_nodes: ["string", "triple_quoted_string"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -401,7 +393,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_gleam() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: ["string"].into(),
+                atom_nodes: ["string"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -417,7 +409,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["interpreted_string_literal", "raw_string_literal"]
+                atom_nodes: ["interpreted_string_literal", "raw_string_literal"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("{", "}"), ("[", "]"), ("(", ")")]
@@ -432,7 +424,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_hack() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["prefixed_string", "heredoc"].into_iter().collect(),
+                atom_nodes: ["prefixed_string", "heredoc"].into_iter().collect(),
                 delimiter_tokens: vec![("[", "]"), ("(", ")"), ("<", ">"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -446,9 +438,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_hare() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_constant", "rune_constant"]
-                    .into_iter()
-                    .collect(),
+                atom_nodes: ["string_constant", "rune_constant"].into_iter().collect(),
                 delimiter_tokens: vec![("[", "]"), ("(", ")"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -463,7 +453,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "qualified_variable",
                     // Work around https://github.com/tree-sitter/tree-sitter-haskell/issues/102
                     "qualified_module",
@@ -483,7 +473,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_hcl() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_lit", "heredoc_template"].into_iter().collect(),
+                atom_nodes: ["string_lit", "heredoc_template"].into_iter().collect(),
                 delimiter_tokens: vec![
                     ("[", "]"),
                     ("(", ")"),
@@ -506,7 +496,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "doctype",
                     "quoted_attribute_value",
                     "raw_text",
@@ -538,7 +528,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_janet_simple() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![].into_iter().collect(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![
                     ("@{", "}"),
                     ("@(", ")"),
@@ -562,7 +552,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "string_literal",
                     // The Java parser has a subnode (boolean_type
                     // ("bool")) for built-in types. This isn't a
@@ -591,9 +581,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "template_string", "regex"]
-                    .into_iter()
-                    .collect(),
+                atom_nodes: ["string", "template_string", "regex"].into_iter().collect(),
                 delimiter_tokens: vec![
                     ("[", "]"),
                     ("(", ")"),
@@ -614,7 +602,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string"].into_iter().collect(),
+                atom_nodes: ["string"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(&language, tree_sitter_json::HIGHLIGHTS_QUERY)
                     .unwrap(),
@@ -627,7 +615,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "string_literal",
                     "prefixed_string_literal",
                     "command_literal",
@@ -652,7 +640,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 // structure of complex types within, but it beats
                 // ignoring nullable changes.
                 // https://github.com/Wilfred/difftastic/issues/411
-                atom_nodes: vec!["line_string_literal", "character_literal", "nullable_type"]
+                atom_nodes: ["line_string_literal", "character_literal", "nullable_type"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]"), ("<", ">")]
@@ -670,7 +658,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_latex() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![].into_iter().collect(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -686,7 +674,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string"].into_iter().collect(),
+                atom_nodes: ["string"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")]
                     .into_iter()
                     .collect(),
@@ -696,16 +684,15 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             }
         }
         Make => {
-            let language = unsafe { tree_sitter_make() };
+            let language_fn = tree_sitter_make::LANGUAGE;
+            let language = tree_sitter::Language::new(language_fn);
+
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["shell_text", "text"].into_iter().collect(),
+                atom_nodes: ["shell_text", "text"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")].into_iter().collect(),
-                highlight_query: ts::Query::new(
-                    &language,
-                    include_str!("../../vendored_parsers/highlights/make.scm"),
-                )
-                .unwrap(),
+                highlight_query: ts::Query::new(&language, tree_sitter_make::HIGHLIGHTS_QUERY)
+                    .unwrap(),
                 sub_languages: vec![TreeSitterSubLanguage {
                     query: ts::Query::new(&language, "(shell_function (shell_command) @contents)")
                         .unwrap(),
@@ -717,7 +704,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_newick() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![].into_iter().collect(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -728,18 +715,17 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             }
         }
         Nix => {
-            let language = unsafe { tree_sitter_nix() };
+            let language_fn = tree_sitter_nix::LANGUAGE;
+            let language = tree_sitter::Language::new(language_fn);
+
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_expression", "indented_string_expression"]
+                atom_nodes: ["string_expression", "indented_string_expression"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("{", "}"), ("[", "]")].into_iter().collect(),
-                highlight_query: ts::Query::new(
-                    &language,
-                    include_str!("../../vendored_parsers/highlights/nix.scm"),
-                )
-                .unwrap(),
+                highlight_query: ts::Query::new(&language, tree_sitter_nix::HIGHLIGHTS_QUERY)
+                    .unwrap(),
                 sub_languages: vec![],
             }
         }
@@ -748,7 +734,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string_literal"].into_iter().collect(),
+                atom_nodes: ["string_literal"].into_iter().collect(),
                 delimiter_tokens: vec![
                     ("(", ")"),
                     ("{", "}"),
@@ -790,7 +776,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_pascal() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![].into_iter().collect(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -804,7 +790,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_perl() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "string_single_quoted",
                     "string_double_quoted",
                     "comments",
@@ -831,7 +817,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "encapsed_string"].into_iter().collect(),
+                atom_nodes: ["string", "encapsed_string"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(&language, tree_sitter_php::HIGHLIGHTS_QUERY)
                     .unwrap(),
@@ -843,7 +829,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string"].into_iter().collect(),
+                atom_nodes: ["string"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(&language, tree_sitter_python::HIGHLIGHTS_QUERY)
                     .unwrap(),
@@ -859,9 +845,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "template_string", "regex"]
-                    .into_iter()
-                    .collect(),
+                atom_nodes: ["string", "template_string", "regex"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(&language, &highlight_query).unwrap(),
                 sub_languages: vec![],
@@ -871,7 +855,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_r() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "special"].into_iter().collect(),
+                atom_nodes: ["string", "special"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -885,7 +869,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_racket() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "byte_string", "regex", "here_string"]
+                atom_nodes: ["string", "byte_string", "regex", "here_string"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
@@ -902,9 +886,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "heredoc_body", "regex"]
-                    .into_iter()
-                    .collect(),
+                atom_nodes: ["string", "heredoc_body", "regex"].into_iter().collect(),
                 delimiter_tokens: vec![
                     ("{", "}"),
                     ("(", ")"),
@@ -920,16 +902,15 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             }
         }
         Rust => {
-            let language = unsafe { tree_sitter_rust() };
+            let language_fn = tree_sitter_rust::LANGUAGE;
+            let language = tree_sitter::Language::new(language_fn);
+
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["char_literal", "string_literal"].into_iter().collect(),
+                atom_nodes: ["char_literal", "string_literal"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("|", "|"), ("<", ">")],
-                highlight_query: ts::Query::new(
-                    &language,
-                    include_str!("../../vendored_parsers/highlights/rust.scm"),
-                )
-                .unwrap(),
+                highlight_query: ts::Query::new(&language, tree_sitter_rust::HIGHLIGHTS_QUERY)
+                    .unwrap(),
                 sub_languages: vec![],
             }
         }
@@ -938,7 +919,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = tree_sitter::Language::new(language_fn);
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "template_string"].into_iter().collect(),
+                atom_nodes: ["string", "template_string"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(&language, tree_sitter_scala::HIGHLIGHTS_QUERY)
                     .unwrap(),
@@ -949,7 +930,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_scheme() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string"].into_iter().collect(),
+                atom_nodes: ["string"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -963,7 +944,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_scss() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["integer_value", "float_value", "color_value"]
+                atom_nodes: ["integer_value", "float_value", "color_value"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")")],
@@ -979,7 +960,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_smali() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: HashSet::from(["string"]),
+                atom_nodes: ["string"].into_iter().collect(),
                 delimiter_tokens: Vec::new(),
                 highlight_query: ts::Query::new(
                     &language,
@@ -993,7 +974,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_solidity() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "hex_string_literal", "unicode_string_literal"]
+                atom_nodes: ["string", "hex_string_literal", "unicode_string_literal"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("[", "]"), ("(", ")"), ("{", "}")],
@@ -1009,7 +990,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_sql() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "identifier"].into_iter().collect(),
+                atom_nodes: ["string", "identifier"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -1023,7 +1004,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_swift() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: ["line_string_literal"].into(),
+                atom_nodes: ["line_string_literal"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -1039,7 +1020,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "quoted_key"].into_iter().collect(),
+                atom_nodes: ["string", "quoted_key"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(&language, tree_sitter_toml_ng::HIGHLIGHTS_QUERY)
                     .unwrap(),
@@ -1055,7 +1036,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "template_string"].into_iter().collect(),
+                atom_nodes: ["string", "template_string"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(&language, &highlight_query).unwrap(),
                 sub_languages: vec![],
@@ -1070,7 +1051,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
 
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["string", "template_string", "regex", "predefined_type"]
+                atom_nodes: ["string", "template_string", "regex", "predefined_type"]
                     .into_iter()
                     .collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
@@ -1087,18 +1068,20 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 // XMLDecl is the <?xml ...?> header, but the parser
                 // just treats it as a sequence of tokens rather than
                 // e.g. string subexpressions, so flatten.
-                atom_nodes: vec!["AttValue", "XMLDecl"].into_iter().collect(),
-                delimiter_tokens: (vec![("<", ">")]),
+                atom_nodes: ["AttValue", "XMLDecl"].into_iter().collect(),
+                delimiter_tokens: vec![("<", ">")],
                 highlight_query: ts::Query::new(&language, tree_sitter_xml::XML_HIGHLIGHT_QUERY)
                     .unwrap(),
                 sub_languages: vec![],
             }
         }
         Yaml => {
-            let language = unsafe { tree_sitter_yaml() };
+            let language_fn = tree_sitter_yaml::LANGUAGE;
+            let language = tree_sitter::Language::new(language_fn);
+
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![
+                atom_nodes: [
                     "string_scalar",
                     "double_quote_scalar",
                     "single_quote_scalar",
@@ -1106,12 +1089,9 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 ]
                 .into_iter()
                 .collect(),
-                delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")]),
-                highlight_query: ts::Query::new(
-                    &language,
-                    include_str!("../../vendored_parsers/highlights/yaml.scm"),
-                )
-                .unwrap(),
+                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
+                highlight_query: ts::Query::new(&language, tree_sitter_yaml::HIGHLIGHTS_QUERY)
+                    .unwrap(),
                 sub_languages: vec![],
             }
         }
@@ -1119,7 +1099,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_vhdl() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec![].into_iter().collect(),
+                atom_nodes: [].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")],
                 highlight_query: ts::Query::new(
                     &language,
@@ -1133,10 +1113,10 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_zig() };
             TreeSitterConfig {
                 language: language.clone(),
-                atom_nodes: vec!["STRINGLITERALSINGLE", "BUILTINIDENTIFIER"]
+                atom_nodes: ["STRINGLITERALSINGLE", "BUILTINIDENTIFIER"]
                     .into_iter()
                     .collect(),
-                delimiter_tokens: (vec![("{", "}"), ("[", "]"), ("(", ")")])
+                delimiter_tokens: vec![("{", "}"), ("[", "]"), ("(", ")")]
                     .into_iter()
                     .collect(),
                 highlight_query: ts::Query::new(
@@ -1284,10 +1264,10 @@ fn tree_highlights(
     let mut qc = ts::QueryCursor::new();
     let mut q_matches = qc.matches(&config.highlight_query, tree.root_node(), src.as_bytes());
 
-    let mut comment_ids = HashSet::new();
-    let mut keyword_ids = HashSet::new();
-    let mut string_ids = HashSet::new();
-    let mut type_ids = HashSet::new();
+    let mut comment_ids = DftHashSet::default();
+    let mut keyword_ids = DftHashSet::default();
+    let mut string_ids = DftHashSet::default();
+    let mut type_ids = DftHashSet::default();
 
     while let Some(m) = q_matches.next() {
         for c in m.captures {
@@ -1511,10 +1491,10 @@ fn find_delim_positions(
 
 #[derive(Debug)]
 pub(crate) struct HighlightedNodeIds {
-    keyword_ids: HashSet<usize>,
-    comment_ids: HashSet<usize>,
-    string_ids: HashSet<usize>,
-    type_ids: HashSet<usize>,
+    keyword_ids: DftHashSet<usize>,
+    comment_ids: DftHashSet<usize>,
+    string_ids: DftHashSet<usize>,
+    type_ids: DftHashSet<usize>,
 }
 
 /// Convert all the tree-sitter nodes at this level to difftastic
